@@ -1,47 +1,26 @@
 package Cinnamon;
 use strict;
 use warnings;
-use 5.010_001;
+use 5.008008;
 
-our $VERSION = '0.13_02';
+our $VERSION = '0.01';
 
-use YAML ();
 use Class::Load ();
 
 use Cinnamon::Config;
 use Cinnamon::Runner;
 use Cinnamon::Logger;
 
-sub new {
-    my $class = shift;
-    bless { }, $class;
-}
-
 sub run {
-    my ($self, $role, $task, %opts)  = @_;
-    my @args     = Cinnamon::Config::load $role, $task, %opts;
-
-    if ($opts{info}) {
-        log 'info', YAML::Dump(Cinnamon::Config::info);
-        return;
-    }
-
-    my $hosts    = Cinnamon::Config::get_role;
-    my $task_def = Cinnamon::Config::get_task;
-    my $runner   = Cinnamon::Config::get('runner_class') || 'Cinnamon::Runner::Concurrent';
-
-    unless (defined $hosts) {
-        log 'error', "undefined role : '$role'";
-        return;
-    }
-    unless (defined $task_def) {
-        log 'error', "undefined task : '$task'";
-        return;
-    }
+    my $class  = shift;
+    my @args   = Cinnamon::Config::load @_;
+    my $hosts  = Cinnamon::Config::get_role || [];
+    my $task   = Cinnamon::Config::get_task;
+    my $runner = Cinnamon::Config::get('runner_class') || 'Cinnamon::Runner';
 
     Class::Load::load_class $runner;
 
-    my $result = $runner->start($hosts, $task_def);
+    my $result = $runner->start($hosts, $task, @args);
     my (@success, @error);
 
     for my $key (keys %{$result || {}}) {
@@ -53,17 +32,11 @@ sub run {
         }
     }
 
-    log success => sprintf(
-        "\n========================\n[success]: %s",
+    log info => sprintf(
+        "\n========================\n[success]: %s\n[error]: %s",
         (join(', ', @success) || ''),
-    );
-
-    log error => sprintf(
-        "[error]: %s",
         (join(', ', @error)   || ''),
     );
-
-    return (\@success, \@error);
 }
 
 !!1;
@@ -302,7 +275,7 @@ C<$stderr>, as strings.
 
   my ($stdout, $stdout) = sudo '/path/to/httpd', 'restart';
 
-Executes a command as well, but under I<sudo> environment.
+Execultes a command as well, but under I<suod> environment.
 
 =back
 
@@ -332,27 +305,15 @@ https://github.com/kentaro/cinnamon
 
 =head1 AUTHOR
 
-=over 4
+Kentaro Kuribayashi E<lt>kentarok@gmail.comE<gt>
 
-=item * Kentaro Kuribayashi E<lt>kentarok@gmail.comE<gt>
-
-=item * Yuki Shibazaki E<lt>shibayu36 at gmail.comE<gt>
-
-=back
+Yuki Shibazaki E<lt>shibayu36 at gmail.comE<gt>
 
 =head1 SEE ALSO
 
-=over 4
+L<capistrano>
 
-=item * Tutorial (Japanese)
-
-L<http://d.hatena.ne.jp/naoya/20130118/1358477523>
-
-=item * L<capistrano>
-
-=item * L<Archer>
-
-=back
+L<Archer>
 
 =head1 LICENSE
 
