@@ -2,29 +2,30 @@ package Cinnamon::Config;
 use strict;
 use warnings;
 
+use Coro;
+use Coro::RWLock;
 use Cinnamon::Config::Loader;
-use Cinnamon::Logger;
 
 my %CONFIG;
 my %ROLES;
 my %TASKS;
 
-sub reset () {
-    %CONFIG = ();
-    %ROLES  = ();
-    %TASKS  = ();
-}
+my $lock = new Coro::RWLock;
 
 sub set ($$) {
     my ($key, $value) = @_;
 
+    $lock->wrlock;
     $CONFIG{$key} = $value;
+    $lock->unlock;
 }
 
 sub get ($@) {
     my ($key, @args) = @_;
 
+    $lock->rdlock;
     my $value = $CONFIG{$key};
+    $lock->unlock;
 
     $value = $value->(@args) if ref $value eq 'CODE';
     $value;
@@ -33,42 +34,45 @@ sub get ($@) {
 sub set_role ($$$) {
     my ($role, $hosts, $params) = @_;
 
+    $lock->wrlock;
     $ROLES{$role} = [$hosts, $params];
+    $lock->unlock;
 }
 
 sub get_role (@) {
-    my $role  = ($_[0] || get('role'));
+    my $role  = ($_[0] || get('role')) or die "no role";
 
-    my $role_def = $ROLES{$role} or return undef;
-
-    my ($hosts, $params) = @$role_def;
+    $lock->rdlock;
+    my ($hosts, $params) = @{$ROLES{$role}};
+    $lock->unlock;
 
     for my $key (keys %$params) {
         set $key => $params->{$key};
     }
 
     $hosts = $hosts->() if ref $hosts eq 'CODE';
-    $hosts = [] unless defined $hosts;
-    $hosts = ref $hosts eq 'ARRAY' ? $hosts : [$hosts];
-
-    return $hosts;
+    ref $hosts eq 'ARRAY' ? $hosts : [$hosts];
 }
 
 sub set_task ($$) {
     my ($task, $task_def) = @_;
+    $lock->wrlock;
     $TASKS{$task} = $task_def;
+    $lock->unlock;
 }
 
 sub get_task (@) {
     my ($task) = @_;
 
-    $task ||= get('task');
+    $task ||= get('task') or die "no task";
     my @task_path = split(':', $task);
 
+    $lock->rdlock;
     my $value = \%TASKS;
     for (@task_path) {
         $value = $value->{$_};
     }
+    $lock->unlock;
 
     $value;
 }
@@ -82,30 +86,12 @@ sub user () {
 }
 
 sub load (@) {
-    my ($role, $task, %opt) = @_;
+    my ($role, $task) = (shift, shift);
 
     set role => $role;
     set task => $task;
 
-    Cinnamon::Config::Loader->load(config => $opt{config});
-
-    for my $key (keys %{ $opt{override_settings} }) {
-        set $key => $opt{override_settings}->{$key};
-    }
-}
-
-sub info {
-    my $self  = shift;
-    my %roles = map {
-        my ($hosts, $params) = @{$ROLES{$_}};
-        $hosts = $hosts->() if ref $hosts eq 'CODE';
-        $_ => { hosts => $hosts, params => $params };
-    } keys %ROLES;
-
-    +{
-        roles => \%roles,
-        tasks => \%TASKS,
-    }
+    Cinnamon::Config::Loader->load(@_);
 }
 
 !!1;
